clear
set more off
cd

**********************************************************************************
* This do file estimates the relationship between operating expenditure and scale
* variables applicable for the 2020-2025 draft price-qualilty path reset for EDBs 
**********************************************************************************

******************************
***   	OUTLIER CODE	   ***
******************************

* This code is used to test whether individual observations are statistical outliers

program drop _all
program define test_outlier

predict yhattt, xb
predict e, residuals
predict lev, leverage
predict dfits, dfits
predict wd, welsch
predict cooksd, cooksd

gen k = e(df_m) + 1 		/*e(N) = sample size, k = no. of independent variables including constant*/

gen g1=1 if abs(dfits)>2*sqrt(k/e(N)) 
gen dfits_outlier_stat=abs(dfits)

gen g2=1 if abs(cooksd)>4/e(N)
gen cooksd_outlier_stat=abs(cooksd)

gen g3=1 if abs(wd)>3*sqrt(k)
gen wd_outlier_stat=abs(wd)

gen g4=1 if lev>((2*k)/e(N))
gen lev_outlier_stat=abs(lev)

foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
}

gen sum_outlier = g1 + g2 + g3 + g4

list edb year sum_outlier if sum_outlier > 1
drop  yhattt e lev dfits wd cooksd k g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier 

end

* This generates an outlier test that can be applied following a regression - to run the test use 'test_outlier'


***************************************************
***		IMPORT INFORMATION DISCLOSURE DATA		***
***************************************************

use "Opex econometrics - dataset.dta", clear
	* This dataset is compiled from data from information disclosure
	* All opex value have been converted to constant 2018 dollars

* Convert to logs (for log-log regression analysis)
foreach var in ARR BS Delivery ICP Lines Network Nonnetwork OH Opex Peak RCMI SIE SONS UG VM {
	replace `var' = log(`var')
}

***************************
***   NETWORK OPEX  	***
***************************

* Initial regression to identify outliers
reg Network Lines ICP 
test_outlier

* Outliers listed with sum of outliers of 3/4 (ie, the number of outlier tests breached)
capture drop outlier
gen outlier = 0
replace outlier = 1 if (edb == "Nelson Electricity" & year == 2016)
replace outlier = 1 if (edb == "Nelson Electricity" & year == 2018)

* Run regression again with sample excluding outliers
reg Network Lines ICP if outlier == 0
test_outlier

replace outlier = 1 if (edb == "Nelson Electricity" & year == 2015)
reg Network Lines ICP if outlier == 0
test_outlier
// No further outliers found

* Examine adjusted R-squared, AIC and BIC
ereturn	list r2_a 
estat ic

* Test residuals, AV plots and omitted variables
reg Network Lines ICP if outlier == 0
avplots
ovtest /*cannot reject the null of no misspecification*/
estat imtest, white /*cannot reject the null of homoscedasticity (at 5% level)*/
hettest /*cannot reject the null of homoscedastic errors*/

* Test normality of residuals
predict res, resid
swilk res
histogram res, normal bin(20)
drop res

* Testing whether coefficients differ for non-exempt EDBs
reg Network Lines ICP exempt if outlier == 0
test exempt	
// Exempt dummy variable is not statistically significant

* Testing predictive power of model 
// Note: Below line indicates model under-predicts opex. Above line indicates model over-predicts opex
reg Network Lines ICP if outlier == 0
estat ic
predict yhat, xb
scatter Network yhat if exempt == 0, xscale(r(6(1)11))  xlabel(#6) xtitle("ln(Network opex)") ///
ytitle("predicted ln(Network opex)") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) ||lfit Network yhat, lcolor(black) 
graph save "Network opex prediction v actual", replace
sort yhat
list edb yhat Network
drop yhat

*** Draft decision - model used for network opex ***
reg Network Lines ICP if outlier == 0
ereturn	list r2_a 
estat ic

	
****************************
***   NON-NETWORK OPEX   ***
****************************

* Initial regression to identify outliers
reg Nonnetwork Lines ICP 
test_outlier

* Outliers listed with sum of outliers of 3/4 (ie, the number of outlier tests breached)
capture drop outlier
gen outlier = 0
replace outlier = 1 if (edb == "Buller Electricity" & year == 2013)

* Run regression again with sample excluding outliers
reg Nonnetwork Lines ICP if outlier == 0
test_outlier

replace outlier = 1 if (edb == "Buller Electricity" & year == 2014)
reg Nonnetwork Lines ICP if outlier == 0
test_outlier
// No further outliers found

* Examine adjusted R-squared, AIC and BIC
ereturn	list r2_a 
estat ic

* Test residuals, AV plots and omitted variables
reg Nonnetwork Lines ICP if outlier == 0
avplots
ovtest /*cannot reject the null of no misspecification*/
estat imtest, white /*cannot reject the null of homoscedasticity (at 5% level)*/
hettest /*cannot reject the null of homoscedastic errors*/

* Test normality of residuals
predict res, resid
swilk res
histogram res, normal bin(20)
drop res

* Testing whether coefficients differ for non-exempt EDBs
reg Nonnetwork Lines ICP exempt if outlier == 0
test exempt	
// Exempt dummy variable is statistically significant at 5% level

* Testing predictive power of model 
// Note: Below line indicates model under-predicts opex. Above line indicates model over-predicts opex
reg Nonnetwork Lines ICP if outlier == 0
estat ic
predict yhat, xb
scatter Nonnetwork yhat if exempt == 0, xscale(r(6(1)11))  xlabel(#6) xtitle("ln(Non-network opex)") ///
ytitle("predicted ln(Non-network opex)") graphregion(color("white") icolor("white") lcolor("white") fcolor("white")) plotregion(icolor("white") margin(zero)) ///
legend(off) ylabel(, nogrid) ||lfit Nonnetwork yhat, lcolor(black) 
graph save "Non-network opex prediction v actual", replace
sort yhat
list edb yhat Nonnetwork
drop yhat

*** Draft decision - model used for non-network opex ***
reg Nonnetwork Lines ICP if outlier == 0
ereturn	list r2_a 
estat ic


****************************************************
*** General experimentation of other regressions ***
****************************************************

reg Opex Lines ICP Delivery Peak
reg Network Lines ICP Delivery Peak
reg Nonnetwork Lines ICP Delivery Peak

reg ARR Lines ICP Delivery Peak if year>=2014
reg BS Lines ICP Delivery Peak if year>=2014
reg RCMI Lines ICP Delivery Peak if year>=2014
reg SIE Lines ICP Delivery Peak if year>=2014
reg SONS Lines ICP Delivery Peak if year>=2014
reg VM OH ICP Delivery Peak if year>=2014

*** Recommended narrow regression scope ***
reg Opex Lines ICP
reg Network Lines ICP
reg Nonnetwork Lines ICP
reg Nonnetwork ICP

reg ARR Lines ICP if year>=2014
reg ARR OH ICP if year>=2014
reg BS ICP if year>=2014
reg RCMI Delivery if year>=2014
reg SIE Lines ICP if year>=2014
reg SONS Lines Peak if year>=2014
reg VM OH if year>=2014

* For each experiment test for outliers and replace accordingly
capture drop outlier
test_outlier
gen outlier = 0
// replace outlier = 1 if ...

reg Opex Lines ICP if outlier==0
reg Network Lines ICP if outlier==0
reg Nonnetwork Lines ICP if outlier==0
reg Nonnetwork ICP if outlier==0

reg ARR Lines ICP if year>=2014 & outlier==0
reg ARR OH ICP if year>=2014 & outlier==0
reg BS ICP if year>=2014 & outlier==0
reg RCMI Delivery if year>=2014 & outlier==0
reg SIE Lines ICP if year>=2014 & outlier==0
reg SONS Lines Peak if year>=2014 & outlier==0
reg VM OH if year>=2014 & outlier==0

*For each experiment run statistical tests as above
exit
